@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Extracts a file from a ZIP file, and saves it as the given file name.
 #
 # Author: Frank Steggink
@@ -29,6 +27,13 @@ class ZipFileExtractor(Filter):
         """
         pass
 
+    @Config(ptype=bool, default=True, required=False)
+    def delete_file(self):
+        """
+        Delete the file when the chain has been completed?
+        """
+        pass
+
     # End attribute config meta
 
     # Constructor
@@ -58,7 +63,7 @@ class ZipFileExtractor(Filter):
 
     def after_chain_invoke(self, packet):
         import os.path
-        if os.path.isfile(self.cur_file_path):
+        if os.path.isfile(self.cur_file_path) and self.delete_file:
             os.remove(self.cur_file_path)
 
         return True
