@@ -1,19 +1,27 @@
-# -*- coding: utf-8 -*-
-#
 # Utility functions and classes.
 #
 # Author:Just van den Broecke
 
+import glob
 import logging
 import os
-import glob
+import re
 import types
 from time import time
-from ConfigParser import ConfigParser
+from configparser import ConfigParser
 
 logging.basicConfig(level=logging.INFO,
                     format='%(asctime)s %(name)s %(levelname)s %(message)s')
 
+# Constants for precompiled regular expressions
+RE_PG_START = re.compile(r'\bPG:', flags=re.IGNORECASE)
+RE_PG_PWD = re.compile(r'\bpassword=[^\'"]\S*', flags=re.IGNORECASE)
+RE_PG_PWD_DBL = re.compile(r'\bpassword="(?:[^"\\]|\\.)*"', flags=re.IGNORECASE)
+RE_PG_PWD_SNG = re.compile(r'\bpassword=\'(?:[^\'\\]|\\.)*\'', flags=re.IGNORECASE)
+RE_PG_USER = re.compile(r'\buser=[^\'"]\S*', flags=re.IGNORECASE)
+RE_PG_USER_DBL = re.compile(r'\buser="(?:[^"\\]|\\.)*"', flags=re.IGNORECASE)
+RE_PG_USER_SNG = re.compile(r'\buser=\'(?:[^\'\\]|\\.)*\'', flags=re.IGNORECASE)
+
 
 # Static utility methods
 class Util:
@@ -44,9 +52,9 @@ class Util:
     xslt_strip_ns_doc = False
 
     @staticmethod
-    def get_log(name):
+    def get_log(name, level=logging.DEBUG):
         log = logging.getLogger(name)
-        log.setLevel(logging.DEBUG)
+        log.setLevel(level)
         return log
 
     @staticmethod
@@ -126,11 +134,17 @@ class Util:
     def propsfile_to_dict(file_path):
         # See http://stackoverflow.com/questions/2819696/parsing-properties-file-in-python
         # Need a [section] header to parse .ini files, so fake it!
-        class FakeSecHead(object):
+        class FakeSecHead:
             def __init__(self, fp):
                 self.fp = fp
                 self.sechead = '[asection]\n'
 
+            def __iter__(self):
+                return self
+
+            def __next__(self):
+                return self.readline()
+
             def readline(self):
                 if self.sechead:
                     try:
@@ -138,7 +152,11 @@ class Util:
                     finally:
                         self.sechead = None
                 else:
-                    return self.fp.readline()
+                    line = self.fp.readline()
+                    if line:
+                        return line
+                    else:
+                        raise StopIteration
 
         cp = ConfigParser()
         cp.readfp(FakeSecHead(open(file_path)))
@@ -237,6 +255,8 @@ class Util:
 
                 # Create OGR Geometry object from GML string
                 value = etree.tostring(subelem)
+                if type(value) == bytes:
+                    value = value.decode('utf-8')
                 from osgeo import ogr
                 geom = ogr.CreateGeometryFromGML(value)
 
@@ -329,7 +349,7 @@ class Util:
                           ]
                }
 
-            print xpath_get(foo, "/morefoo/0/morebar/bacon")
+            print (xpath_get(foo, "/morefoo/0/morebar/bacon"))
 
         :param mydict: a nested dict
         :param path: path to member
@@ -348,19 +368,28 @@ class Util:
 
         return elem
 
+    # Hide user names and passwords in string values, like the Postgres connection string as used by GDAL/OGR
+    # See https://stackoverflow.com/questions/249791/regex-for-quoted-string-with-escaping-quotes for the escaped quotes expressions
+    @staticmethod
+    def safe_string_value(value, hide_value='***'):
+        # PostgreSQL connection strings as used by GDAL/OGR
+        if RE_PG_START.search(value) is not None:
+            value = RE_PG_PWD.sub('password=%s' % hide_value, value)
+            value = RE_PG_PWD_DBL.sub('password="%s"' % hide_value, value)
+            value = RE_PG_PWD_SNG.sub('password=\'%s\'' % hide_value, value)
+
+            value = RE_PG_USER.sub('user=%s' % hide_value, value)
+            value = RE_PG_USER_DBL.sub('user="%s"' % hide_value, value)
+            value = RE_PG_USER_SNG.sub('user=\'%s\'' % hide_value, value)
+
+        # Add more cases as needed ...
+
+        return value
+
 
 log = Util.get_log("util")
 
 # Try several imports, centralized to give warnings once
-try:
-    from cStringIO import StringIO
-
-    log.info("Found cStringIO, good!")
-except Exception:
-    from StringIO import StringIO
-
-    log.warning("Found %s - this is suboptimal, try cStringIO" % str(type(StringIO)))
-
 try:
     from lxml import etree
 
@@ -488,9 +517,14 @@ class ConfigSection():
         # Need to hide some sensitive values, usually used for logging
         safe_copy = self.config_dict.copy()
         hides = ['passw', 'pasw', 'token', 'user']
+        hide_value = '<hidden>'
+
         for key in safe_copy:
             for hide_key in hides:
                 if hide_key in key.lower():
-                    safe_copy[key] = '<hidden>'
+                    safe_copy[key] = hide_value
+
+            # Also hide usernames/passwords  in string values, like Postgres connection strings used by GDAL/OGR
+            safe_copy[key] = Util.safe_string_value(safe_copy[key], hide_value)
 
         return repr(safe_copy)
