@@ -23,7 +23,7 @@ class XmlElementStreamerFileInputTest(StetlTestCase):
         section = StetlTestCase.get_section(chain)
         class_name = self.etl.configdict.get(section, 'class')
         
-        self.assertEqual('inputs.fileinput.XmlElementStreamerFileInput', class_name)
+        self.assertEqual('stetl.inputs.fileinput.XmlElementStreamerFileInput', class_name)
     
     def test_instance(self):
         chain = StetlTestCase.get_chain(self.etl)
